@@ -30,7 +30,6 @@ except ImportError:
     from urlparse import urlparse
 
 
-DELAY = 3
 DEFAULT_PORT = 22
 
 swallow_http_errors = True
@@ -428,15 +427,21 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
 
         for command in commands:
             try:
-                _, stdout, _ = ssh.exec_command(command, get_pty=True)
+                _, stdout, _ = ssh.exec_command(command,
+                                                get_pty=True,
+                                                timeout=1)
             except paramiko.SSHException as exc:
                 logging.info(str(exc))
             else:
-                data = stdout.read()
-                logging.debug('{!r} => {!r}'.format(command, data))
-                result = self.parse_encoding(data)
-                if result:
-                    return result
+                try:
+                    data = stdout.read()
+                except socket.timeout:
+                    pass
+                else:
+                    logging.debug('{!r} => {!r}'.format(command, data))
+                    result = self.parse_encoding(data)
+                    if result:
+                        return result
 
         logging.warning('Could not detect the default encoding.')
         return 'utf-8'
@@ -515,8 +520,7 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
                 clients[ip] = workers
             worker.src_addr = (ip, port)
             workers[worker.id] = worker
-            self.loop.call_later(options.delay or DELAY, recycle_worker,
-                                 worker)
+            self.loop.call_later(options.delay, recycle_worker, worker)
             self.result.update(id=worker.id, encoding=worker.encoding)
 
         self.write(self.result)
