@@ -7,7 +7,7 @@ from webssh import handler
 from webssh.handler import IndexHandler, WsockHandler, NotFoundHandler
 from webssh.settings import (
     get_app_settings,  get_host_keys_settings, get_policy_setting,
-    get_ssl_context, get_server_settings
+    get_ssl_context, get_server_settings, check_encoding_setting
 )
 
 
@@ -42,6 +42,7 @@ def app_listen(app, port, address, server_settings):
 
 def main():
     options.parse_command_line()
+    check_encoding_setting(options.encoding)
     loop = tornado.ioloop.IOLoop.current()
     app = make_app(make_handlers(loop, options), get_app_settings(options))
     ssl_ctx = get_ssl_context(options)
